@@ -69,7 +69,7 @@ int RemoteDesktopsModel::rowCount(const QModelIndex &) const
 Qt::ItemFlags RemoteDesktopsModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return nullptr;
+        return Qt::NoItemFlags;
     if (index.column() == RemoteDesktopsModel::Favorite) {
         return Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
     }
